@@ -78,7 +78,7 @@
 
 // Type indices
 enum : int {
-    SBK_QGL_IDX                                              = 4,
+    SBK_QtOpenGLQGL_IDX                                      = 4,
     SBK_QGL_FORMATOPTION_IDX                                 = 5,
     SBK_QFLAGS_QGL_FORMATOPTION_IDX                          = 0,
     SBK_QGLBUFFER_IDX                                        = 6,
@@ -105,13 +105,13 @@ enum : int {
     SBK_QtOpenGL_IDX_COUNT                                   = 24
 };
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtOpenGLTypes;
+extern PyTypeObject **SbkPySide2_QtOpenGLTypes;
 
 // This variable stores the Python module object exported by this module.
-extern PyObject* SbkPySide2_QtOpenGLModuleObject;
+extern PyObject *SbkPySide2_QtOpenGLModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtOpenGLTypeConverters;
+extern SbkConverter **SbkPySide2_QtOpenGLTypeConverters;
 
 // Converter indices
 enum : int {
@@ -130,29 +130,29 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QGL::FormatOption >() { return SbkPySide2_QtOpenGLTypes[SBK_QGL_FORMATOPTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QFlags<QGL::FormatOption> >() { return SbkPySide2_QtOpenGLTypes[SBK_QFLAGS_QGL_FORMATOPTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QGLBuffer::Type >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLBUFFER_TYPE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QGLBuffer::UsagePattern >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLBUFFER_USAGEPATTERN_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QGLBuffer::Access >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLBUFFER_ACCESS_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QGLBuffer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtOpenGLTypes[SBK_QGLBUFFER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QGLColormap >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtOpenGLTypes[SBK_QGLCOLORMAP_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QGLContext::BindOption >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLCONTEXT_BINDOPTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QFlags<QGLContext::BindOption> >() { return SbkPySide2_QtOpenGLTypes[SBK_QFLAGS_QGLCONTEXT_BINDOPTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QGLContext >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtOpenGLTypes[SBK_QGLCONTEXT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QGLFormat::OpenGLContextProfile >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLFORMAT_OPENGLCONTEXTPROFILE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QGLFormat::OpenGLVersionFlag >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLFORMAT_OPENGLVERSIONFLAG_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QFlags<QGLFormat::OpenGLVersionFlag> >() { return SbkPySide2_QtOpenGLTypes[SBK_QFLAGS_QGLFORMAT_OPENGLVERSIONFLAG_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QGLFormat >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtOpenGLTypes[SBK_QGLFORMAT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QGLFramebufferObject::Attachment >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECT_ATTACHMENT_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QGLFramebufferObject >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QGLFramebufferObjectFormat >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECTFORMAT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QGLPixelBuffer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtOpenGLTypes[SBK_QGLPIXELBUFFER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QGLShader::ShaderTypeBit >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLSHADER_SHADERTYPEBIT_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QFlags<QGLShader::ShaderTypeBit> >() { return SbkPySide2_QtOpenGLTypes[SBK_QFLAGS_QGLSHADER_SHADERTYPEBIT_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QGLShader >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtOpenGLTypes[SBK_QGLSHADER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QGLShaderProgram >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtOpenGLTypes[SBK_QGLSHADERPROGRAM_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QGLWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtOpenGLTypes[SBK_QGLWIDGET_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGL::FormatOption >() { return SbkPySide2_QtOpenGLTypes[SBK_QGL_FORMATOPTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QGL::FormatOption> >() { return SbkPySide2_QtOpenGLTypes[SBK_QFLAGS_QGL_FORMATOPTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QGLBuffer::Type >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLBUFFER_TYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QGLBuffer::UsagePattern >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLBUFFER_USAGEPATTERN_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QGLBuffer::Access >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLBUFFER_ACCESS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QGLBuffer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLBUFFER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGLColormap >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLCOLORMAP_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGLContext::BindOption >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLCONTEXT_BINDOPTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QGLContext::BindOption> >() { return SbkPySide2_QtOpenGLTypes[SBK_QFLAGS_QGLCONTEXT_BINDOPTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QGLContext >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLCONTEXT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGLFormat::OpenGLContextProfile >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLFORMAT_OPENGLCONTEXTPROFILE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QGLFormat::OpenGLVersionFlag >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLFORMAT_OPENGLVERSIONFLAG_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QGLFormat::OpenGLVersionFlag> >() { return SbkPySide2_QtOpenGLTypes[SBK_QFLAGS_QGLFORMAT_OPENGLVERSIONFLAG_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QGLFormat >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLFORMAT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGLFramebufferObject::Attachment >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECT_ATTACHMENT_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QGLFramebufferObject >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGLFramebufferObjectFormat >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECTFORMAT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGLPixelBuffer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLPIXELBUFFER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGLShader::ShaderTypeBit >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLSHADER_SHADERTYPEBIT_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QGLShader::ShaderTypeBit> >() { return SbkPySide2_QtOpenGLTypes[SBK_QFLAGS_QGLSHADER_SHADERTYPEBIT_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QGLShader >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLSHADER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGLShaderProgram >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLSHADERPROGRAM_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGLWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLWIDGET_IDX]); }
 
 } // namespace Shiboken
 
