@@ -53,7 +53,7 @@
 #include <pyside2_qtwidgets_python.h>
 
 // Binded library includes
-#include <qscriptenginedebugger.h>
+#include <QtScriptTools/qscriptenginedebugger.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -81,13 +81,13 @@ enum : int {
     SBK_QtScriptTools_IDX_COUNT                              = 4
 };
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtScriptToolsTypes;
+extern PyTypeObject **SbkPySide2_QtScriptToolsTypes;
 
 // This variable stores the Python module object exported by this module.
-extern PyObject* SbkPySide2_QtScriptToolsModuleObject;
+extern PyObject *SbkPySide2_QtScriptToolsModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtScriptToolsTypeConverters;
+extern SbkConverter **SbkPySide2_QtScriptToolsTypeConverters;
 
 // Converter indices
 enum : int {
@@ -104,10 +104,10 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QScriptEngineDebugger::DebuggerWidget >() { return SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERWIDGET_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QScriptEngineDebugger::DebuggerAction >() { return SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERACTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QScriptEngineDebugger::DebuggerState >() { return SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERSTATE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QScriptEngineDebugger >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QScriptEngineDebugger::DebuggerWidget >() { return SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERWIDGET_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QScriptEngineDebugger::DebuggerAction >() { return SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERACTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QScriptEngineDebugger::DebuggerState >() { return SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERSTATE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QScriptEngineDebugger >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_IDX]); }
 
 } // namespace Shiboken
 
