@@ -71,17 +71,17 @@
 
 // Type indices
 enum : int {
-    SBK_QTWEBENGINE_IDX                                      = 0,
+    SBK_QtWebEngineQTWEBENGINE_IDX                           = 0,
     SBK_QtWebEngine_IDX_COUNT                                = 1
 };
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtWebEngineTypes;
+extern PyTypeObject **SbkPySide2_QtWebEngineTypes;
 
 // This variable stores the Python module object exported by this module.
-extern PyObject* SbkPySide2_QtWebEngineModuleObject;
+extern PyObject *SbkPySide2_QtWebEngineModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtWebEngineTypeConverters;
+extern SbkConverter **SbkPySide2_QtWebEngineTypeConverters;
 
 // Converter indices
 enum : int {
